<?php


function petittheme_setup() {

// テーマの更新通知
require_once( 'theme-update-checker.php' );
$update_checker = new ThemeUpdateChecker(
    'PHStheme',
    'https://dcpndsgn.com/clover/wptheme/update-info.json'
);

// 公開画面で Gutenberg用 の CSSを追加読込
add_theme_support( 'wp-block-styles' );

// 縦横比を維持したままレスポンシブ
add_theme_support( 'responsive-embeds' );

// エディタページにCSSを適用
add_theme_support( 'editor-styles' );
add_editor_style( 'editor-style.css' );

// titleタグ出力
add_theme_support( 'title-tag' );

// link, style, script のHTML5対応有効化
add_theme_support( 'html5', array( 'style', 'script' ));

// アイキャッチ画像を有効化（無効中）
// add_theme_support( 'post-thumbnails' );

// 全幅・幅広を有効化
add_theme_support( 'align-wide' );

// ページ上部メニューのロケーションを登録
register_nav_menus( array( 'primary' => 'ナビゲーション' ));
}
add_action('after_setup_theme', 'petittheme_setup' );

// Google Fontsを読み込み
function petittheme_enqueue() {
wp_enqueue_style (
'petit_font',
'https://fonts.googleapis.com/css?family=M+PLUS+Rounded+1c:400,700&display=swap',
array(),
null
);

// Dashiconsを読み込み
wp_enqueue_style( 'dashicons' );
wp_enqueue_style( 'petittheme-style', get_stylesheet_uri(), array(), filemtime(get_theme_file_path('style.css')) );
}
add_action('wp_enqueue_scripts', 'petittheme_enqueue' );

//ウィジェットエリアを登録
function petittheme_widgets() {
register_sidebar( array(
'id' => 'sidebar-1',
'name' => 'フッターメニュー',
'before_widget' => '<section id="%1$s" class="widget %2$s">',
'after_widget' => '</section>'
));
}
add_action( 'widgets_init', 'petittheme_widgets' );

//いただいたコメントの表示制御
function petit_comment($comment, $args, $depth) {
$GLOBALS['comment'] = $comment; ?>

<p class="comment_info">
<?php comment_author_link(); ?> | <?php comment_date(); ?> <?php comment_time(); ?>
</p>
<li class="comment_post">
<?php comment_text(); ?>
<?php
}

//特定カテゴリを除外する（自分専用）
//function exclude_category( $query )
//{
//if ( $query->is_home() && $query->is_main_query() ) {
//$query->set( 'cat', '-16' ); //マイナスを付けてカテゴリIDを除外
//}
//}
//add_action( 'pre_get_posts', 'exclude_category' );

//記事の並び順（date.phpでは日付の古いものからにする）
function my_orderby_modified( $query ) {
	if( $query->is_main_query() ) {
		if( $query->is_date() ) {
			$query->set( 'orderby', 'date' );
			$query->set( 'order', 'ASC' );
		}
	}
}
add_action( 'pre_get_posts', 'my_orderby_modified' );



// テーマカスタマイザー設定 ここから
// //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function theme_customizer_extension($wp_customize) {


// セクション //////////////////////////////////////////////////////////////////////////////
// タイトルを画像にする //////////////////////////////////////////
$wp_customize->add_section( 'theme_title_customize', array(
'title' => 'タイトル画像',
'priority' => 30,
));
// 背景画像 //////////////////////////////////////////
$wp_customize->add_section( 'theme_background_image_customize', array (
'title' => '背景画像',	
'priority' => 30,
));
// きせかえシステム風 //////////////////////////////////////////
$wp_customize->add_section( 'theme_kisekae_customize', array (
'title' => 'きせかえシステム風',	
'priority' => 30,
));
// 色設定 //////////////////////////////////////////
$wp_customize->add_section( 'theme_color_customize', array (
'title' => '色',
'priority' => 35,
));
// フォント //////////////////////////////////////////
$wp_customize->add_section( 'theme_font', array (
'title' => 'フォント',
'priority' => 40,
));
// パーツの表示・非表示 //////////////////////////////////////////
$wp_customize->add_section( 'theme_parts_visible', array (
'title' => 'パーツの表示・非表示',
'priority' => 110,
));
// メニュー間の仕切り //////////////////////////////////////////
$wp_customize->add_section( 'theme_menu_separator', array (
'title' => 'メニュー間の仕切り',
'priority' => 111,
));
// ページナビの文字列 //////////////////////////////////////////
$wp_customize->add_section( 'theme_page_nav_customize', array (
'title' => 'ページナビの文字列',
'priority' => 113,
));
// ホームページ全体の横幅・中央揃え //////////////////////////////////////////
$wp_customize->add_section( 'theme_wide_customize', array (
'title' => 'ホームページ全体の横幅・中央揃え',
'priority' => 115,
));



// セッティングとコントロール //////////////////////////////////////////////////////////////////////////////
// タイトル画像 //////////////////////////////////////////
$wp_customize->add_setting( 'title_image_url' );
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'title_image_url', array(
'label' => 'ロゴ画像',
'section' => 'theme_title_customize',
'settings' => 'title_image_url',
'description' => 'ロゴ画像を設定してください。',
)));
// 背景画像 //////////////////////////////////////////
$wp_customize->add_setting( 'background_image_url', array(
'sanitize_callback' => 'esc_url_raw'
));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,'background_image_url', array(
'label' => 'ページ全体の背景画像',
'section' => 'theme_background_image_customize',
'settings' => 'background_image_url',
'priority' => 20,
'description' => 'ページ全体に背景画像を敷き詰めます。未選択の場合は、色の設定項目で指定した「ページ全体の背景色」が反映されます。',
)));
$wp_customize->add_setting( 'paper_background_image_url', array(
'sanitize_callback' => 'esc_url_raw'
));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,'paper_background_image_url', array(
'label' => '紙部分の背景画像',
'section' => 'theme_background_image_customize',
'settings' => 'paper_background_image_url',
'priority' => 20,
'description' => '紙部分に背景画像を敷き詰めます。空欄の場合は、色の設定項目で指定した「紙部分の背景色」が反映されます。',
)));
$wp_customize->add_setting( 'analink_background_image_url', array(
'sanitize_callback' => 'esc_url_raw'
));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,'analink_background_image_url', array(
'label' => 'プチ穴部分の背景画像',
'section' => 'theme_background_image_customize',
'settings' => 'analink_background_image_url',
'priority' => 20,
'description' => 'プチ穴部分に背景画像を敷き詰めます。空欄の場合は、色の設定項目で指定した「紙部分の背景色」が反映されます。',
)));

// きせかえシステム風 //////////////////////////////////////////
$wp_customize->add_setting( 'kisekae_background_image', array(
'default' => '',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kisekae_background_image', array(
'section' => 'theme_kisekae_customize',
'settings' => 'kisekae_background_image',
'label' => 'ページ全体の背景画像',
'priority' => 30,
'type' => 'select',
'choices' => array(
		'' => '選択しない',
		'01_linen_kinari.jpg' => 'リネン 生成',
		'02_linen_bdr_aka_t.jpg' => 'リネンボーダー赤 縦',
		'02_linen_bdr_aka_y.jpg' => 'リネンボーダー赤 横',
		'03_linen_bdr_kuro_t.jpg' => 'リネンボーダー黒 縦',
		'03_linen_bdr_kuro_y.jpg' => 'リネンボーダー黒 横',
		'04_linen_bdr_aka_t.jpg' => 'リネンボーダー2赤 縦',
		'04_linen_bdr_aka_y.jpg' => 'リネンボーダー2赤 横',
		'05_walnut1_t.jpg' => 'ウォールナット1 縦',
		'05_walnut1_y.jpg' => 'ウォールナット1 横',
		'06_walnut2_t.jpg' => 'ウォールナット2 縦',
		'06_walnut2_y.jpg' => 'ウォールナット2 横',
		'07_chanpaka_t.jpg' => 'チャンパカ 縦',
		'07_chanpaka_y.jpg' => 'チャンパカ 横',
		'08_antique_teak_t.jpg' => 'アンティークチーク 縦',
		'08_antique_teak_y.jpg' => 'アンティークチーク 横',
		'09_akamatsu_t.jpg' => '赤松 縦',
		'09_akamatsu_y.jpg' => '赤松 横',
		'10_PetitGrand_background_red_on_white.gif' => 'プチグラ（赤と白）',
		'10_PetitGrand_background_white_on_red.gif' => 'プチグラ（白と赤）',
		'11_PetitGrand_background_red_on_red.gif' => 'プチグラ（赤と赤）',
		'11_PetitGrand_background_white_on_white.gif' => 'プチグラ（白と白）',
		'12_Xmas07_background_green.png' => 'スノーステッチ 緑',
		'12_Xmas07_background_red.png' => 'スノーステッチ 赤',
		'12_Xmas07_background_white.png' => 'スノーステッチ 白',
		'13_tartan_a.gif' => 'タータン1（ななめ）',
		'13_tartan_b.gif' => 'タータン1（縦横）',
		'14_tartan_a.gif' => 'タータン2（ななめ）',
		'14_tartan_b.gif' => 'タータン2（縦横）',
		'16_tartan_a.gif' => 'タータン3（ななめ）',
		'16_tartan_b.gif' => 'タータン3（縦横）',
		'17_tartan_a.gif' => 'タータン4（ななめ）',
		'17_tartan_b.gif' => 'タータン4（縦横）',
		'18_tartan_a.gif' => 'タータン5（ななめ）',
		'18_tartan_b.gif' => 'タータン5（縦横）',
		'15_tartan_a.gif' => 'タータン6（ななめ）',
		'15_tartan_b.gif' => 'タータン6（縦横）',
		'19_corkboard.jpg' => 'コルクボード',
),
)));

$wp_customize->add_setting( 'kisekae_paper_image', array(
'default' => '',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kisekae_paper_image', array(
'section' => 'theme_kisekae_customize',
'settings' => 'kisekae_paper_image',
'label' => '紙部分の背景画像',
'priority' => 30,
'type' => 'select',
'choices' => array(
		'' => '選択しない',
		'01_warabanshi.png' => 'わら半紙',
		'06_kiiroi_kami.png' => '黄色い厚紙',
		'08_craft.png' => 'クラフトペーパー',
		'09_drawing_blue.jpg' => '色画用紙（青）',
		'09_drawing_gray.jpg' => '色画用紙（灰色）',
		'09_drawing_pink.jpg' => '色画用紙（ピンク）',
),
)));

$wp_customize->add_setting( 'kisekae_analink_image', array(
'default' => '',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kisekae_analink_image', array(
'section' => 'theme_kisekae_customize',
'settings' => 'kisekae_analink_image',
'label' => 'プチ穴部分の背景画像',
'priority' => 30,
'type' => 'select',
'choices' => array(
		'' => '選択しない',
		'01_warabanshi.png' => 'わら半紙',
		'06_kiiroi_kami.png' => '黄色い厚紙',
		'08_craft.png' => 'クラフトペーパー',
		'09_drawing_blue.jpg' => '色画用紙（青）',
		'09_drawing_gray.jpg' => '色画用紙（灰色）',
		'09_drawing_pink.jpg' => '色画用紙（ピンク）',
),
)));



// 色設定 //////////////////////////////////////////
// 文字色
$wp_customize->add_setting( 'text_color', array(
'default' => '#666666',
'sanitize_callback' => 'sanitize_text_field'
));
$wp_customize->add_control( 'text_color', array(
'description' => '各所の色は、カラーコード欄を空欄にすると透明になります。<br>色 < 背景画像 < きせかえシステム風 の順番で優先的に表示されます。',
'label' =>'文字色',
'section' => 'theme_color_customize',
'settings' => 'text_color',
'priority' => 20,
));
// リンク文字色
$wp_customize->add_setting( 'link_text_color', array(
'default' => '#666666',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'link_text_color', array(
'label' =>'リンク文字色',
'section' => 'theme_color_customize',
'settings' => 'link_text_color',
'priority' => 20,
));
// リンク文字列下線の表示・非表示
$wp_customize->add_setting( 'link_text_underline', array(
'default' => false,
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'link_text_underline', array(
'description' => 'チェックを入れるとリンクの設定された文字列に下線を引きます。',
'label' => 'リンク文字列下線を表示する',
'section' => 'theme_color_customize',
'settings' => 'link_text_underline',
'priority' => 20,
'type' => 'checkbox',
));
// ページ全体の背景色
$wp_customize->add_setting( 'body_color', array(
'default' => '#999999',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'body_color', array(
'label' =>'ページ全体の背景色',
'section' => 'theme_color_customize',
'settings' => 'body_color',
'priority' => 20,
));
// 紙部分の背景色
$wp_customize->add_setting( 'paper_color', array(
'default' => '#FFFFFF',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'paper_color', array(
'label' =>'紙部分の背景色',
'section' => 'theme_color_customize',
'settings' => 'paper_color',
'priority' => 20,
));
// プチ穴部分の色
$wp_customize->add_setting( 'analink_color', array(
'default' => '#666666',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'analink_color', array(
'description' => 'プチ穴部分も紙と同じ色 または 画像にする場合は空欄にしてください。',
'label' =>'プチ穴部分の色',
'section' => 'theme_color_customize',
'settings' => 'analink_color',
'priority' => 20,
));
// 紙の影の色
$wp_customize->add_setting( 'shadow_color', array(
'default' => '#888888',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'shadow_color', array(
'description' => 'パーツの表示・非表示で「影なし」以外の場合の影の色を指定できます。',
'label' =>'紙の影の色',
'section' => 'theme_color_customize',
'settings' => 'shadow_color',
'priority' => 40,
));
// 紙の枠線の色
$wp_customize->add_setting( 'line_color', array(
'default' => 'transparent',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'line_color', array(
'label' =>'紙の枠線の色',
'section' => 'theme_color_customize',
'settings' => 'line_color',
'priority' => 50,
));
// 紙の枠線の表示・非表示
$wp_customize->add_setting( 'paper_outline', array(
'default' => true,
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'paper_outline', array(
'description' => 'プチの紙部分を囲む枠線の表示・非表示を切り替えます。チェックを外すと枠線は透明になります。',
'label' => '紙の枠線を表示する',
'section' => 'theme_color_customize',
'settings' => 'paper_outline',
'priority' => 50,
'type' => 'checkbox',
));
// 点々線の色
$wp_customize->add_setting( 'dotline_color', array(
'default' => '#888888',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'dotline_color', array(
'label' =>'点々線の色',
'section' => 'theme_color_customize',
'settings' => 'dotline_color',
'priority' => 60,
));

// フォント //////////////////////////////////////////
$wp_customize->add_setting( 'theme_font_size', array(
'default' => '11',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_setting( 'alphabet_font', array(
'default' => 'Arial',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'theme_font_size', array(
'section' => 'theme_font',
'settings' => 'theme_font_size',
'label' => 'フォントサイズ',
'priority' => 30,
)));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'alphabet_font', array(
'section' => 'theme_font',
'settings' => 'alphabet_font',
'label' => 'アルファベット書体',
'priority' => 30,
'type' => 'radio',
'choices' => array(
		'Arial' => 'Arial',
		'Arial Black' => 'Arial Black',
		'Verdana' => 'Verdana',
		'Impact' => 'Impact',
		'Trebuchet MS' => 'Trebuchet MS',
		'Courier New' => 'Courier New',
		'Georgia' => 'Georgia',
		'Times New Roman' => 'Times New Roman',
),
)));



// パーツの表示・非表示 //////////////////////////////////////////
// プチ穴部分の表示・非表示
$wp_customize->add_setting( 'analink_display', array(
'default' => true,
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'analink_display', array(
'description' => 'プチ上部のプチ穴部分の表示・非表示を切り替えます。<br>チェックボックスをONにすると表示されます。',
'label' => 'プチ穴部分を表示する',
'section' => 'theme_parts_visible',
'settings' => 'analink_display',
'priority' => 30,
'type' => 'checkbox',
));
// 紙の影の表示・非表示
$wp_customize->add_setting( 'shadow_type', array(
'default' => 'oldfashioned',
'type' => 'option',
'transport' => 'refresh',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'shadow_type', array(
'description' => '紙の影部分の表示・非表示を切り替えます。<br>お好みのタイプを選択してください。',
'section' => 'theme_parts_visible',
'settings' => 'shadow_type',
'label' => '紙の影の表示・非表示',
'priority' => 30,
'type' => 'radio',
'choices' => array(
		'oldfashioned' => 'プチのデフォルト',
		'kisekae' => 'きせかえシステム風',
		'noshadow' => '影なし',
),
)));
// 写真の角丸
$wp_customize->add_setting( 'theme_img_radius', array(
'default' => false,
'sanitize_callback' => 'sanitize_text_field'
));
$wp_customize->add_control( 'theme_img_radius', array(
'label' => '投稿画像の角丸',
'section' => 'theme_parts_visible',
'settings' => 'theme_img_radius',
'priority' => 30,
'type' => 'checkbox',
'description' => '投稿画像の角を丸くします。'
));
// SNSボタンの表示・非表示
$wp_customize->add_setting( 'theme_sns_visible', array(
'defalut' => 'true',
'sanitize_callback' => 'sanitize_text_field'
));
$wp_customize->add_control( 'theme_sns_visible', array(
'label' => 'SNSボタンの表示・非表示',
'section' => 'theme_parts_visible',
'settings' => 'theme_sns_visible',
'priority' => 30,
'type' => 'checkbox',
'description' => 'SNSシェアボタンの表示・非表示を切り替えます。チェックを入れると表示します。'
));

// メニュー間の仕切り //////////////////////////////////////////
// ページ上部のメニュー間の仕切り
$wp_customize->add_setting( 'theme_menu_separator_left', array(
'default' => '|',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_menu_separator_left', array(
'label' => '左端',
'section' => 'theme_menu_separator',
'settings' => 'theme_menu_separator_left',
'priority' => 20,
));
$wp_customize->add_setting( 'theme_menu_separator_middle', array(
'default' => '|',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_menu_separator_middle', array(
'label' => '中間',
'section' => 'theme_menu_separator',
'settings' => 'theme_menu_separator_middle',
'priority' => 20,
));
$wp_customize->add_setting( 'theme_menu_separator_right', array(
'default' => '|',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_menu_separator_right', array(
'label' => '右端',
'section' => 'theme_menu_separator',
'settings' => 'theme_menu_separator_right',
'priority' => 20,
'description' => 'ページ上部のメニュー部分の仕切りを変更できます。',
));


// ページナビ・アーカイブリストの文字列 //////////////////////////////////////////
// ページナビの文字列
$wp_customize->add_setting( 'theme_page_nav_customize_next', array(
'default' => 'Next',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_page_nav_customize_next', array(
'label' => '左側',
'section' => 'theme_page_nav_customize',
'settings' => 'theme_page_nav_customize_next',
'priority' => 20,
));
$wp_customize->add_setting( 'theme_page_nav_customize_back', array(
'default' => 'Back',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_page_nav_customize_back', array(
'label' => '右側',
'section' => 'theme_page_nav_customize',
'settings' => 'theme_page_nav_customize_back',
'priority' => 20,
));
$wp_customize->add_setting( 'theme_page_nav_customize_oldlog', array(
'default' => 'Old Log',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_page_nav_customize_oldlog', array(
'label' => 'アーカイブリストの見出し（未動作）',
'section' => 'theme_page_nav_customize',
'settings' => 'theme_page_nav_customize_oldlog',
'priority' => 20,
));


// ホームページ全体の横幅・中央揃え //////////////////////////////////////////
// ホームページ全体の横幅
$wp_customize->add_setting( 'theme_wide', array(
'default' => '600',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_wide', array(
'label' => 'ホームページ全体の横幅',
'section' => 'theme_wide_customize',
'settings' => 'theme_wide',
'priority' => 60,
'description' => 'プチの紙に該当する部分の横幅を入力してください。※画像サイズは、記事の投稿時に自由に変更できます。',
));
// 中央揃え
$wp_customize->add_setting( 'theme_wrap_petit_content_position', array(
'default' => true,
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_wrap_petit_content_position', array(
'label' => 'ホームページ全体を中央揃えにする',
'section' => 'theme_wide_customize',
'settings' => 'theme_wrap_petit_content_position',
'priority' => 60,
'type' => 'checkbox',
'description' => 'プチ全体をブラウザのウィンドウに対して中央揃えにする設定です。中央揃えにする場合、チェックボックスをONにしてください。',
));
// 紙内側の余白
$wp_customize->add_setting('theme_side_margin_left', array(
'default' => '35',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_setting('theme_side_margin_right', array(
'default' => '35',
'sanitize_callback' => 'sanitize_text_field',
));
$wp_customize->add_control( 'theme_side_margin_left', array(
'label' => '紙内側の余白（左）',
'section' => 'theme_wide_customize',
'settings' => 'theme_side_margin_left',
'priority' => '65',
));
$wp_customize->add_control( 'theme_side_margin_right', array(
'label' => '紙内側の余白（右）',
'section' => 'theme_wide_customize',
'settings' => 'theme_side_margin_right',
'priority' => '65',
));

}
add_action('customize_register', 'theme_customizer_extension');






// テーマカスタマイザーの内容を読み込み //////////////////////////////////////////////////////////////////////////////
// アップロードしたタイトル画像 //////////////////////////////////////////////////////////////////////////////////////////
function get_the_logo_url(){
	return esc_url( get_theme_mod( 'title_image_url' ) );
}


// アップロードした背景画像 //////////////////////////////////////////////////////////////////////////////////////////
function background_image_url() {
?>

<!-- ページ全体の背景画像 -->
<style type="text/css">
<?php
if ( get_theme_mod( 'background_image_url' ) ) {
$background_image_url = get_theme_mod( 'background_image_url' );
} else {
$background_image_url = get_stylesheet_directory_uri() . '';
}
// if ( 0 < count( strlen( ( $background_image_url = get_theme_mod( 'background_image_url', sprintf( '', get_stylesheet_directory_uri() ) ) ) ) ) ) { ?>
html { background-image: url( '<?php echo $background_image_url; ?>' ); }
<?php // } // end if ?>
</style>

<?php
}
add_action( 'wp_head', 'background_image_url');

// アップロードした紙部分画像 //////////////////////////////////////////////////////////////////////////////////////////
function paper_background_image_url() {
?>
<!-- 紙部分の背景画像 -->
<style type="text/css">
<?php
if ( get_theme_mod( 'paper_background_image_url' ) ) {
$paper_background_image_url = get_theme_mod( 'paper_background_image_url' );
} else {
$paper_background_image_url = get_stylesheet_directory_uri() . '';
}
// if ( 0 < count( strlen( ( $paper_background_image_url = get_theme_mod( 'paper_background_image_url', sprintf( '', get_stylesheet_directory_uri() ) ) ) ) ) ) { ?>
#paper { background-image: url( '<?php echo $paper_background_image_url; ?>' ); }
<?php // } // end if ?>
</style>

<?php
}
add_action( 'wp_head', 'paper_background_image_url');

// アップロードしたプチ穴部分画像 //////////////////////////////////////////////////////////////////////////////////////////
function analink_background_image_url() {
?>
<!-- プチ穴部分の背景画像 -->
<style type="text/css">
<?php
if ( get_theme_mod( 'analink_background_image_url' ) ) {
$analink_background_image_url = get_theme_mod( 'analink_background_image_url' );
} else {
$analink_background_image_url = get_stylesheet_directory_uri() . '';
}
// if ( 0 < count( strlen( ( $analink_background_image_url = get_theme_mod( 'analink_background_image_url', sprintf( '', get_stylesheet_directory_uri() ) ) ) ) ) ) { ?>
#upload_ana_link { background-image: url( '<?php echo $analink_background_image_url; ?>' ); }
<?php // } // end if ?>
</style>

<?php
}
add_action( 'wp_head', 'analink_background_image_url');


// きせかえシステム風 //////////////////////////////////////////////////////////////////////////////////////////
function kisekae_background_image() {
$kisekae_background_image = get_option( 'kisekae_background_image' );
?>
<!-- きせかえシステム風で設定したページ全体の背景画像 -->
<style type="text/css">
body { background-image: url( "<?php echo get_template_directory_uri(); ?>/images/background/<?php echo $kisekae_background_image ?>" ); }
</style>

<?php
}
add_action( 'wp_head', 'kisekae_background_image');

function kisekae_paper_image() {
$kisekae_paper_image = get_option( 'kisekae_paper_image' );
?>
<!-- きせかえシステム風で設定した紙部分の背景画像 -->
<style type="text/css">
#kisekae_paper { background-image: url( "<?php echo get_template_directory_uri(); ?>/images/content/<?php echo $kisekae_paper_image ?>" ); }
</style>

<?php
}
add_action( 'wp_head', 'kisekae_paper_image');

function kisekae_analink_image() {
$kisekae_analink_image = get_option( 'kisekae_analink_image' );
?>
<!-- きせかえシステム風で設定したプチ穴部分の背景画像 -->
<style type="text/css">
#kisekae_ana_link { background-image: url( "<?php echo get_template_directory_uri(); ?>/images/content/<?php echo $kisekae_analink_image ?>" ); }
</style>

<?php
}
add_action( 'wp_head', 'kisekae_analink_image');


function customizer_color() {
$body_color = get_theme_mod( 'body_color', '#999999' ) ;
$paper_color = get_theme_mod( 'paper_color', '#FFFFFF' ) ;
$text_color = get_theme_mod( 'text_color', '#666666' ) ;
$link_text_color = get_theme_mod( 'link_text_color', '#666666' ) ;
$analink_color = get_theme_mod( 'analink_color', '#666666' ) ;
$shadow_type = get_theme_mod( 'shadow_type', 'oldfashioned') ;
$shadow_color = get_theme_mod( 'shadow_color', '#888888' ) ;
$line_color = get_theme_mod( 'line_color', 'transparent' ) ;
$dotline_color = get_theme_mod( 'dotline_color', '#888888' ) ;
?>
<!-- 色設定 -->
<style type="text/css">
body {
background-color: <?php echo $body_color ?> ;
}
body, a, .input_ja, .input2_ja, .input_en {
color: <?php echo $text_color ?> ;
}
.form-submit input  {
color: <?php echo $text_color ?> ;
}
a {
color: <?php echo $link_text_color ?> ;
}
#ana_link {
background-color: <?php echo $analink_color ?> ;
}
#paper, input, textarea {
background-color: <?php echo $paper_color ?> ;
}
.dotline {
border-bottom: 1px dashed <?php echo $dotline_color ?> ;
}
#paper.oldfashioned {
box-shadow: 5px 5px <?php echo $shadow_color ?> ;
}
#paper.kisekae {
box-shadow: 0 0 8px <?php echo $shadow_color ?> ;
}
#paper.noshadow {
box-shadow: none ;
}
</style>

<?php
if ( get_theme_mod( 'link_text_underline', true ) )  : ?>
<!-- リンク文字列の下線 -->
<style type="text/css">
a { text-decoration: underline ; }
</style>

<?php else : ?>
<!-- リンク文字列の下線 -->
<style type="text/css">
a { text-decoration: none ; }
</style>

<?php endif ;


if ( get_theme_mod( 'paper_outline', true ) )  : ?>
<!-- 紙部分の枠線 -->
<style type="text/css">
#paper.line {
border: 1px solid <?php echo $line_color ?> ; }
</style>

<?php else : ?>
<!-- 紙部分の枠線 -->
<style type="text/css">
#paper.line {
border: 0 ;
}
</style>

<?php endif ;
}
add_action( 'wp_head', 'customizer_color' );


// フォント
function theme_font() {
?>
<!-- フォント -->
<style type="text/css">
body {
	font-size: <?php echo get_option( 'theme_font_size', '11' ) ?>pt ;
}
.title_en, .main_en, .navi_en,
.petit-text a,
.cat_post_link,
#grobal_nav li,
#posted_comments .posted-comment-title,
#leave_comments #reply-title,
input.submit, input.wpcf7-submit, #submit,
.related h2,
.archive_title,
.nav-links .navi_en,
.sidebar h2,
footer {
font-family: '<?php echo get_option( 'alphabet_font', 'Arial' ) ?>', sans-serif ;
}
</style>

<?php
}
add_action( 'wp_head', 'theme_font' );




function theme_parts_visible() {
?>
<?php
if ( get_theme_mod( 'theme_img_radius', true ) )  : ?>
<!-- 投稿画像の角丸 -->
<style type="text/css">
.wp-block-media-text img,
.wp-block-image img,
.petit-images__item img,
.wp-block-embed-youtube iframe {
border-radius: 5px ;
}
.wp-block-image.alignfull img {
border-radius: 0 ;
}
</style>

<?php else : ?>
<!-- 投稿画像の角丸なし -->
<style type="text/css">
.wp-block-media-text img,
.wp-block-img img,
.petit-images__item img {
border-radius: 0 ; }
</style>

<?php endif ;
?>



<?php
if ( get_theme_mod( 'theme_sns_visible', true ) ) : ?>
<!-- SNSシェアボタンを表示する -->
<style type="text/css">
#share_button { display: block ; }
</style>

<?php else : ?>
<!-- SNSシェアボタンを非表示にする -->
<style type="text/css">
#share_button { display: none ; }
</style>

<?php endif ;
}
add_action( 'wp_head', 'theme_parts_visible' );



function theme_menu_separator() {
$theme_menu_separator_left = get_theme_mod( 'theme_menu_separator_left', '|');
$theme_menu_separator_middle = get_theme_mod( 'theme_menu_separator_middle', '|');
$theme_menu_separator_right = get_theme_mod( 'theme_menu_separator_right', '|');
?>
<!-- メニュー間の仕切り -->
<style type="text/css">
#grobal_nav li:first-child,
#grobal_nav li:not(:first-child) {
margin-right: 0.25em ;
}
#grobal_nav li:first-child:before {
content: "<?php echo $theme_menu_separator_left ?>" ;
margin-right: 0.5em ;
}
#grobal_nav li:not(:first-child):before {
content: "<?php echo $theme_menu_separator_middle ?>" ;
margin-right: 0.5em ;
}
#grobal_nav li:last-child:after {
content: "<?php echo $theme_menu_separator_right ?>" ;
margin-left: 0.5em ;
}
</style>

<?php
}
add_action( 'wp_head', 'theme_menu_separator' );


function theme_wide_customize() {
$theme_wide = get_theme_mod( 'theme_wide', '600');
$theme_side_margin_left = get_theme_mod( 'theme_side_margin_left', '35' );
$theme_side_margin_right = get_theme_mod( 'theme_side_margin_right', '35' );
?>
<!-- ホームページ全体の横幅 -->
<style type="text/css">
@media only screen and (min-width: 768px) {
#paper {
width: <?php echo $theme_wide ?>px ; }
#paper_inner {
width: calc(<?php echo $theme_wide ?>px - <?php echo $theme_side_margin_right ?>px - <?php echo $theme_side_margin_left ?>px ) ;
margin: 0 <?php echo $theme_side_margin_right ?>px 0 <?php echo $theme_side_margin_left ?>px ;
}
.dotline {
margin-right: -<?php echo $theme_side_margin_right ?>px ;
margin-left: -<?php echo $theme_side_margin_left ?>px ; }
}
.alignfull {
margin-right: -<?php echo $theme_side_margin_right ?>px ;
margin-left: -<?php echo $theme_side_margin_left ?>px ;
max-width: none ;
width: auto ;
}

</style>

<?php
if ( get_theme_mod( 'theme_wrap_petit_content_position', true ) )  : ?>
<!-- ホームページ全体の中央揃え -->
<style type="text/css">
#paper {
position: relative ;
margin-right: auto ;
margin-left: auto ;
text-align: left ;
}
</style>

<?php endif ;
}
add_action( 'wp_head', 'theme_wide_customize');